"{ Package: 'stx:libbasic2' }"

"{ NameSpace: Smalltalk }"

LimitedPrecisionReal variableByteSubclass:#HalfFloat
	instanceVariableNames:''
	classVariableNames:''
	poolDictionaries:''
	category:'Magnitude-Numbers'
!

!HalfFloat class methodsFor:'documentation'!

documentation
"
    HalfFloats represent rational numbers with very very limited precision.
    There are no instances of it to be created - halfFloats are only possibly stored
    inside instancs of HalfFloatArray, which are presented as floats or shortFloats when accessd.
    However, this class is provided for queries about precision, bits in mantissa etc.
    They use the C-compiler's 'float' format, which is usually the IEEE single float format.

    Representation:
            16bit single precision IEEE floats
            10 bit fraction + 1 hidden bit, providing a precision of 11bits,
            5 bit exponent,
            6 decimal digits (approx.)

    Range and Precision of Storage Formats: see LimitedPrecisionReal >> documentation

    [author:]
        Claus Gittinger

    [see also:]
        Number
        Float LongFloat Fraction FixedPoint Integer Complex
        HalfFloatArray FloatArray DoubleArray
"
! !

!HalfFloat class methodsFor:'queries'!

eBias
    "Answer the exponent's bias; 
     that is the offset of the zero exponent when stored"

    ^ 15
!

emax
    ^ 15
!

emin
    ^ -14
!

numBitsInExponent
    "answer the number of bits in the exponent
     This is an IEEE float, where 4 bits are available:
        seeeemmm mmmmmmmm
    "

    ^ 4
! !

!HalfFloat class methodsFor:'documentation'!

version_CVS
    ^ '$Header$'
! !

